from setuptools import setup, find_packages

setup(
	name="gtdb",
	version="0.2.0",
	author="Asror bek",
	author_email="minecraftakk2009beta@gmail.com",
	description="It is more convenient to manage a JSON file",
	packages=find_packages(),
    python_requires='>=3.8'
)